axiom package
=============

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   axiom.drs
   axiom.validation

Submodules
----------

axiom.config module
-------------------

.. automodule:: axiom.config
   :members:
   :undoc-members:
   :show-inheritance:

axiom.converters module
-----------------------

.. automodule:: axiom.converters
   :members:
   :undoc-members:
   :show-inheritance:

axiom.decorators module
-----------------------

.. automodule:: axiom.decorators
   :members:
   :undoc-members:
   :show-inheritance:

axiom.drs module
----------------

.. automodule:: axiom.drs
   :members:
   :undoc-members:
   :show-inheritance:

axiom.exceptions module
-----------------------

.. automodule:: axiom.exceptions
   :members:
   :undoc-members:
   :show-inheritance:

axiom.report module
-------------------

.. automodule:: axiom.report
   :members:
   :undoc-members:
   :show-inheritance:

axiom.utilities module
----------------------

.. automodule:: axiom.utilities
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: axiom
   :members:
   :undoc-members:
   :show-inheritance:
